[dtest] Tests added for V3 and V4 Code Objects with Static Lds
- Added test for V3 Static Lds code object with sramecc/xnack settings. - Added test for V4 Static Lds code object. SWDEV-238517 for enhancing hip unit tests Change-Id: Ibc4f7e12033dec231d6834ccdd983e3b9e001d60
Dieser Commit ist enthalten in:
committet von
Mohan Kumar Mithur
Ursprung
12063cfc45
Commit
4c2e91c772
@@ -0,0 +1,37 @@
|
||||
/*
|
||||
Copyright (c) 2020 Advanced Micro Devices, Inc. All rights reserved.
|
||||
Permission is hereby granted, free of charge, to any person obtaining a copy
|
||||
of this software and associated documentation files (the "Software"), to deal
|
||||
in the Software without restriction, including without limitation the rights
|
||||
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
|
||||
copies of the Software, and to permit persons to whom the Software is
|
||||
furnished to do so, subject to the following conditions:
|
||||
The above copyright notice and this permission notice shall be included in
|
||||
all copies or substantial portions of the Software.
|
||||
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANNTY OF ANY KIND, EXPRESS OR
|
||||
IMPLIED, INNCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
|
||||
FITNNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
|
||||
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANNY CLAIM, DAMAGES OR OTHER
|
||||
LIABILITY, WHETHER INN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
|
||||
OUT OF OR INN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
|
||||
THE SOFTWARE.
|
||||
*/
|
||||
|
||||
kernel void add(global float* output, global float* input) {
|
||||
__local float lds[100];
|
||||
int id = get_global_id(0);
|
||||
|
||||
if (id == 0) {
|
||||
for (int i = 0; i < 100; i++) {
|
||||
lds[i] = input[i];
|
||||
}
|
||||
}
|
||||
|
||||
barrier(CLK_LOCAL_MEM_FENCE);
|
||||
|
||||
if (id < 100) {
|
||||
output[id] = lds[id];
|
||||
} else {
|
||||
output[id] = input[id];
|
||||
}
|
||||
}
|
||||
In neuem Issue referenzieren
Einen Benutzer sperren